
#ifndef VTKPVADAPTORSPHASTA_EXPORT_H
#define VTKPVADAPTORSPHASTA_EXPORT_H

#ifdef VTKPVADAPTORSPHASTA_STATIC_DEFINE
#  define VTKPVADAPTORSPHASTA_EXPORT
#  define VTKPVADAPTORSPHASTA_NO_EXPORT
#else
#  ifndef VTKPVADAPTORSPHASTA_EXPORT
#    ifdef AdaptorsPhasta_EXPORTS
        /* We are building this library */
#      define VTKPVADAPTORSPHASTA_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVADAPTORSPHASTA_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVADAPTORSPHASTA_NO_EXPORT
#    define VTKPVADAPTORSPHASTA_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVADAPTORSPHASTA_DEPRECATED
#  define VTKPVADAPTORSPHASTA_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVADAPTORSPHASTA_DEPRECATED_EXPORT
#  define VTKPVADAPTORSPHASTA_DEPRECATED_EXPORT VTKPVADAPTORSPHASTA_EXPORT VTKPVADAPTORSPHASTA_DEPRECATED
#endif

#ifndef VTKPVADAPTORSPHASTA_DEPRECATED_NO_EXPORT
#  define VTKPVADAPTORSPHASTA_DEPRECATED_NO_EXPORT VTKPVADAPTORSPHASTA_NO_EXPORT VTKPVADAPTORSPHASTA_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVADAPTORSPHASTA_NO_DEPRECATED
#    define VTKPVADAPTORSPHASTA_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVAdaptorsPhastaModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVADAPTORSPHASTA_EXPORT_H */
